import * as pulumi from "@pulumi/pulumi";
/**
 * The ``AWS::ApiGatewayV2::ApiMapping`` resource contains an API mapping. An API mapping relates a path of your custom domain name to a stage of your API. A custom domain name can have multiple API mappings, but the paths can't overlap. A custom domain can map only to APIs of the same protocol type. For more information, see [CreateApiMapping](https://docs.aws.amazon.com/apigatewayv2/latest/api-reference/domainnames-domainname-apimappings.html#CreateApiMapping) in the *Amazon API Gateway V2 API Reference*.
 */
export declare class ApiMapping extends pulumi.CustomResource {
    /**
     * Get an existing ApiMapping resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): ApiMapping;
    /**
     * Returns true if the given object is an instance of ApiMapping.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is ApiMapping;
    /**
     * The identifier of the API.
     */
    readonly apiId: pulumi.Output<string>;
    /**
     * The API mapping resource ID.
     */
    readonly apiMappingId: pulumi.Output<string>;
    /**
     * The API mapping key.
     */
    readonly apiMappingKey: pulumi.Output<string | undefined>;
    /**
     * The domain name.
     */
    readonly domainName: pulumi.Output<string>;
    /**
     * The API stage.
     */
    readonly stage: pulumi.Output<string>;
    /**
     * Create a ApiMapping resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: ApiMappingArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a ApiMapping resource.
 */
export interface ApiMappingArgs {
    /**
     * The identifier of the API.
     */
    apiId: pulumi.Input<string>;
    /**
     * The API mapping key.
     */
    apiMappingKey?: pulumi.Input<string>;
    /**
     * The domain name.
     */
    domainName: pulumi.Input<string>;
    /**
     * The API stage.
     */
    stage: pulumi.Input<string>;
}
