import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Definition of AWS::Bedrock::AgentAlias Resource Type
 */
export declare function getAgentAlias(args: GetAgentAliasArgs, opts?: pulumi.InvokeOptions): Promise<GetAgentAliasResult>;
export interface GetAgentAliasArgs {
    /**
     * Id for an Agent Alias generated at the server side.
     */
    agentAliasId: string;
    /**
     * Identifier for a resource.
     */
    agentId: string;
}
export interface GetAgentAliasResult {
    /**
     * Arn representation of the Agent Alias.
     */
    readonly agentAliasArn?: string;
    /**
     * The list of history events for an alias for an Agent.
     */
    readonly agentAliasHistoryEvents?: outputs.bedrock.AgentAliasHistoryEvent[];
    /**
     * Id for an Agent Alias generated at the server side.
     */
    readonly agentAliasId?: string;
    /**
     * Name for a resource.
     */
    readonly agentAliasName?: string;
    /**
     * The status of the alias of the agent and whether it is ready for use. The following statuses are possible:
     *
     * - CREATING – The agent alias is being created.
     * - PREPARED – The agent alias is finished being created or updated and is ready to be invoked.
     * - FAILED – The agent alias API operation failed.
     * - UPDATING – The agent alias is being updated.
     * - DELETING – The agent alias is being deleted.
     * - DISSOCIATED - The agent alias has no version associated with it.
     */
    readonly agentAliasStatus?: enums.bedrock.AgentAliasStatus;
    /**
     * Time Stamp.
     */
    readonly createdAt?: string;
    /**
     * Description of the Resource.
     */
    readonly description?: string;
    /**
     * Routing configuration for an Agent alias.
     */
    readonly routingConfiguration?: outputs.bedrock.AgentAliasRoutingConfigurationListItem[];
    /**
     * Metadata that you can assign to a resource as key-value pairs. For more information, see the following resources:
     *
     * - [Tag naming limits and requirements](https://docs.aws.amazon.com/tag-editor/latest/userguide/tagging.html#tag-conventions)
     * - [Tagging best practices](https://docs.aws.amazon.com/tag-editor/latest/userguide/tagging.html#tag-best-practices)
     */
    readonly tags?: {
        [key: string]: string;
    };
    /**
     * Time Stamp.
     */
    readonly updatedAt?: string;
}
/**
 * Definition of AWS::Bedrock::AgentAlias Resource Type
 */
export declare function getAgentAliasOutput(args: GetAgentAliasOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetAgentAliasResult>;
export interface GetAgentAliasOutputArgs {
    /**
     * Id for an Agent Alias generated at the server side.
     */
    agentAliasId: pulumi.Input<string>;
    /**
     * Identifier for a resource.
     */
    agentId: pulumi.Input<string>;
}
