import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Represents a privacy budget within a collaboration
 */
export declare class PrivacyBudgetTemplate extends pulumi.CustomResource {
    /**
     * Get an existing PrivacyBudgetTemplate resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): PrivacyBudgetTemplate;
    /**
     * Returns true if the given object is an instance of PrivacyBudgetTemplate.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is PrivacyBudgetTemplate;
    /**
     * The ARN of the privacy budget template.
     */
    readonly arn: pulumi.Output<string>;
    /**
     * How often the privacy budget refreshes.
     *
     * > If you plan to regularly bring new data into the collaboration, use `CALENDAR_MONTH` to automatically get a new privacy budget for the collaboration every calendar month. Choosing this option allows arbitrary amounts of information to be revealed about rows of the data when repeatedly queried across refreshes. Avoid choosing this if the same rows will be repeatedly queried between privacy budget refreshes.
     */
    readonly autoRefresh: pulumi.Output<enums.cleanrooms.PrivacyBudgetTemplateAutoRefresh>;
    /**
     * The ARN of the collaboration that contains this privacy budget template.
     */
    readonly collaborationArn: pulumi.Output<string>;
    /**
     * The unique ID of the collaboration that contains this privacy budget template.
     */
    readonly collaborationIdentifier: pulumi.Output<string>;
    /**
     * The Amazon Resource Name (ARN) of the member who created the privacy budget template.
     */
    readonly membershipArn: pulumi.Output<string>;
    /**
     * The identifier for a membership resource.
     */
    readonly membershipIdentifier: pulumi.Output<string>;
    /**
     * Specifies the epsilon and noise parameters for the privacy budget template.
     */
    readonly parameters: pulumi.Output<outputs.cleanrooms.ParametersProperties>;
    /**
     * A unique identifier for one of your memberships for a collaboration. The privacy budget template is created in the collaboration that this membership belongs to. Accepts a membership ID.
     */
    readonly privacyBudgetTemplateIdentifier: pulumi.Output<string>;
    /**
     * Specifies the type of the privacy budget template.
     */
    readonly privacyBudgetType: pulumi.Output<enums.cleanrooms.PrivacyBudgetTemplatePrivacyBudgetType>;
    /**
     * An arbitrary set of tags (key-value pairs) for this cleanrooms privacy budget template.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Create a PrivacyBudgetTemplate resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: PrivacyBudgetTemplateArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a PrivacyBudgetTemplate resource.
 */
export interface PrivacyBudgetTemplateArgs {
    /**
     * How often the privacy budget refreshes.
     *
     * > If you plan to regularly bring new data into the collaboration, use `CALENDAR_MONTH` to automatically get a new privacy budget for the collaboration every calendar month. Choosing this option allows arbitrary amounts of information to be revealed about rows of the data when repeatedly queried across refreshes. Avoid choosing this if the same rows will be repeatedly queried between privacy budget refreshes.
     */
    autoRefresh: pulumi.Input<enums.cleanrooms.PrivacyBudgetTemplateAutoRefresh>;
    /**
     * The identifier for a membership resource.
     */
    membershipIdentifier: pulumi.Input<string>;
    /**
     * Specifies the epsilon and noise parameters for the privacy budget template.
     */
    parameters: pulumi.Input<inputs.cleanrooms.ParametersPropertiesArgs>;
    /**
     * Specifies the type of the privacy budget template.
     */
    privacyBudgetType: pulumi.Input<enums.cleanrooms.PrivacyBudgetTemplatePrivacyBudgetType>;
    /**
     * An arbitrary set of tags (key-value pairs) for this cleanrooms privacy budget template.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
