import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * Resource Type definition for AWS::Connect::User
 */
export declare function getUser(args: GetUserArgs, opts?: pulumi.InvokeOptions): Promise<GetUserResult>;
export interface GetUserArgs {
    /**
     * The Amazon Resource Name (ARN) for the user.
     */
    userArn: string;
}
export interface GetUserResult {
    /**
     * The identifier of the user account in the directory used for identity management.
     */
    readonly directoryUserId?: string;
    /**
     * The identifier of the hierarchy group for the user.
     */
    readonly hierarchyGroupArn?: string;
    /**
     * The information about the identity of the user.
     */
    readonly identityInfo?: outputs.connect.UserIdentityInfo;
    /**
     * The identifier of the Amazon Connect instance.
     */
    readonly instanceArn?: string;
    /**
     * The phone settings for the user.
     */
    readonly phoneConfig?: outputs.connect.UserPhoneConfig;
    /**
     * The identifier of the routing profile for the user.
     */
    readonly routingProfileArn?: string;
    /**
     * One or more security profile arns for the user
     */
    readonly securityProfileArns?: string[];
    /**
     * One or more tags.
     */
    readonly tags?: outputs.Tag[];
    /**
     * The Amazon Resource Name (ARN) for the user.
     */
    readonly userArn?: string;
    /**
     * One or more predefined attributes assigned to a user, with a level that indicates how skilled they are.
     */
    readonly userProficiencies?: outputs.connect.UserProficiency[];
    /**
     * The user name for the account.
     */
    readonly username?: string;
}
/**
 * Resource Type definition for AWS::Connect::User
 */
export declare function getUserOutput(args: GetUserOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetUserResult>;
export interface GetUserOutputArgs {
    /**
     * The Amazon Resource Name (ARN) for the user.
     */
    userArn: pulumi.Input<string>;
}
