import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Resource Type definition for AWS::Connect::QuickConnect
 */
export declare class QuickConnect extends pulumi.CustomResource {
    /**
     * Get an existing QuickConnect resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): QuickConnect;
    /**
     * Returns true if the given object is an instance of QuickConnect.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is QuickConnect;
    /**
     * The description of the quick connect.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * The identifier of the Amazon Connect instance.
     */
    readonly instanceArn: pulumi.Output<string>;
    /**
     * The name of the quick connect.
     */
    readonly name: pulumi.Output<string>;
    /**
     * The Amazon Resource Name (ARN) for the quick connect.
     */
    readonly quickConnectArn: pulumi.Output<string>;
    /**
     * Configuration settings for the quick connect.
     */
    readonly quickConnectConfig: pulumi.Output<outputs.connect.QuickConnectConfig>;
    /**
     * The type of quick connect. In the Amazon Connect console, when you create a quick connect, you are prompted to assign one of the following types: Agent (USER), External (PHONE_NUMBER), or Queue (QUEUE).
     */
    readonly quickConnectType: pulumi.Output<enums.connect.QuickConnectType>;
    /**
     * One or more tags.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Create a QuickConnect resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: QuickConnectArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a QuickConnect resource.
 */
export interface QuickConnectArgs {
    /**
     * The description of the quick connect.
     */
    description?: pulumi.Input<string>;
    /**
     * The identifier of the Amazon Connect instance.
     */
    instanceArn: pulumi.Input<string>;
    /**
     * The name of the quick connect.
     */
    name?: pulumi.Input<string>;
    /**
     * Configuration settings for the quick connect.
     */
    quickConnectConfig: pulumi.Input<inputs.connect.QuickConnectConfigArgs>;
    /**
     * One or more tags.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
