import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Definition of AWS::ControlTower::EnabledBaseline Resource Type
 */
export declare class EnabledBaseline extends pulumi.CustomResource {
    /**
     * Get an existing EnabledBaseline resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): EnabledBaseline;
    /**
     * Returns true if the given object is an instance of EnabledBaseline.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is EnabledBaseline;
    /**
     * The specific `Baseline` enabled as part of the `EnabledBaseline` resource.
     */
    readonly baselineIdentifier: pulumi.Output<string>;
    /**
     * The enabled version of the `Baseline` .
     */
    readonly baselineVersion: pulumi.Output<string>;
    readonly enabledBaselineIdentifier: pulumi.Output<string>;
    /**
     * Shows the parameters that are applied when enabling this `Baseline` .
     */
    readonly parameters: pulumi.Output<outputs.controltower.EnabledBaselineParameter[] | undefined>;
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * The target on which to enable the `Baseline` .
     */
    readonly targetIdentifier: pulumi.Output<string>;
    /**
     * Create a EnabledBaseline resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: EnabledBaselineArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a EnabledBaseline resource.
 */
export interface EnabledBaselineArgs {
    /**
     * The specific `Baseline` enabled as part of the `EnabledBaseline` resource.
     */
    baselineIdentifier: pulumi.Input<string>;
    /**
     * The enabled version of the `Baseline` .
     */
    baselineVersion: pulumi.Input<string>;
    /**
     * Shows the parameters that are applied when enabling this `Baseline` .
     */
    parameters?: pulumi.Input<pulumi.Input<inputs.controltower.EnabledBaselineParameterArgs>[]>;
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
    /**
     * The target on which to enable the `Baseline` .
     */
    targetIdentifier: pulumi.Input<string>;
}
