import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Resource schema for AWS::DataSync::LocationEFS.
 */
export declare class LocationEfs extends pulumi.CustomResource {
    /**
     * Get an existing LocationEfs resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): LocationEfs;
    /**
     * Returns true if the given object is an instance of LocationEfs.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is LocationEfs;
    /**
     * The Amazon Resource Name (ARN) for the Amazon EFS Access point that DataSync uses when accessing the EFS file system.
     */
    readonly accessPointArn: pulumi.Output<string | undefined>;
    /**
     * Specifies the subnet and security groups DataSync uses to connect to one of your Amazon EFS file system's [mount targets](https://docs.aws.amazon.com/efs/latest/ug/accessing-fs.html) .
     */
    readonly ec2Config: pulumi.Output<outputs.datasync.LocationEfsEc2Config>;
    /**
     * The Amazon Resource Name (ARN) for the Amazon EFS file system.
     */
    readonly efsFilesystemArn: pulumi.Output<string | undefined>;
    /**
     * The Amazon Resource Name (ARN) of the AWS IAM role that the DataSync will assume when mounting the EFS file system.
     */
    readonly fileSystemAccessRoleArn: pulumi.Output<string | undefined>;
    /**
     * Protocol that is used for encrypting the traffic exchanged between the DataSync Agent and the EFS file system.
     */
    readonly inTransitEncryption: pulumi.Output<enums.datasync.LocationEfsInTransitEncryption | undefined>;
    /**
     * The Amazon Resource Name (ARN) of the Amazon EFS file system location that is created.
     */
    readonly locationArn: pulumi.Output<string>;
    /**
     * The URL of the EFS location that was described.
     */
    readonly locationUri: pulumi.Output<string>;
    /**
     * A subdirectory in the location's path. This subdirectory in the EFS file system is used to read data from the EFS source location or write data to the EFS destination.
     */
    readonly subdirectory: pulumi.Output<string | undefined>;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Create a LocationEfs resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: LocationEfsArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a LocationEfs resource.
 */
export interface LocationEfsArgs {
    /**
     * The Amazon Resource Name (ARN) for the Amazon EFS Access point that DataSync uses when accessing the EFS file system.
     */
    accessPointArn?: pulumi.Input<string>;
    /**
     * Specifies the subnet and security groups DataSync uses to connect to one of your Amazon EFS file system's [mount targets](https://docs.aws.amazon.com/efs/latest/ug/accessing-fs.html) .
     */
    ec2Config: pulumi.Input<inputs.datasync.LocationEfsEc2ConfigArgs>;
    /**
     * The Amazon Resource Name (ARN) for the Amazon EFS file system.
     */
    efsFilesystemArn?: pulumi.Input<string>;
    /**
     * The Amazon Resource Name (ARN) of the AWS IAM role that the DataSync will assume when mounting the EFS file system.
     */
    fileSystemAccessRoleArn?: pulumi.Input<string>;
    /**
     * Protocol that is used for encrypting the traffic exchanged between the DataSync Agent and the EFS file system.
     */
    inTransitEncryption?: pulumi.Input<enums.datasync.LocationEfsInTransitEncryption>;
    /**
     * A subdirectory in the location's path. This subdirectory in the EFS file system is used to read data from the EFS source location or write data to the EFS destination.
     */
    subdirectory?: pulumi.Input<string>;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
