import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * A data source is used to import technical metadata of assets (data) from the source databases or data warehouses into Amazon DataZone.
 */
export declare function getDataSource(args: GetDataSourceArgs, opts?: pulumi.InvokeOptions): Promise<GetDataSourceResult>;
export interface GetDataSourceArgs {
    /**
     * The ID of the Amazon DataZone domain where the data source is created.
     */
    domainId: string;
    /**
     * The unique identifier of the data source.
     */
    id: string;
}
export interface GetDataSourceResult {
    /**
     * The unique identifier of a connection used to fetch relevant parameters from connection during Datasource run
     */
    readonly connectionId?: string;
    /**
     * The timestamp of when the data source was created.
     */
    readonly createdAt?: string;
    /**
     * The description of the data source.
     */
    readonly description?: string;
    /**
     * The ID of the Amazon DataZone domain where the data source is created.
     */
    readonly domainId?: string;
    /**
     * Specifies whether the data source is enabled.
     */
    readonly enableSetting?: enums.datazone.DataSourceEnableSetting;
    /**
     * The unique identifier of the Amazon DataZone environment to which the data source publishes assets.
     */
    readonly environmentId?: string;
    /**
     * The unique identifier of the data source.
     */
    readonly id?: string;
    /**
     * The number of assets created by the data source during its last run.
     */
    readonly lastRunAssetCount?: number;
    /**
     * The timestamp that specifies when the data source was last run.
     */
    readonly lastRunAt?: string;
    /**
     * The status of the last run of this data source.
     */
    readonly lastRunStatus?: string;
    /**
     * The name of the data source.
     */
    readonly name?: string;
    /**
     * The ID of the Amazon DataZone project to which the data source is added.
     */
    readonly projectId?: string;
    /**
     * Specifies whether the assets that this data source creates in the inventory are to be also automatically published to the catalog.
     */
    readonly publishOnImport?: boolean;
    /**
     * Specifies whether the business name generation is to be enabled for this data source.
     */
    readonly recommendation?: outputs.datazone.DataSourceRecommendationConfiguration;
    /**
     * The schedule of the data source runs.
     */
    readonly schedule?: outputs.datazone.DataSourceScheduleConfiguration;
    /**
     * The status of the data source.
     */
    readonly status?: enums.datazone.DataSourceStatus;
    /**
     * The timestamp of when this data source was updated.
     */
    readonly updatedAt?: string;
}
/**
 * A data source is used to import technical metadata of assets (data) from the source databases or data warehouses into Amazon DataZone.
 */
export declare function getDataSourceOutput(args: GetDataSourceOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetDataSourceResult>;
export interface GetDataSourceOutputArgs {
    /**
     * The ID of the Amazon DataZone domain where the data source is created.
     */
    domainId: pulumi.Input<string>;
    /**
     * The unique identifier of the data source.
     */
    id: pulumi.Input<string>;
}
