import * as pulumi from "@pulumi/pulumi";
import * as enums from "../types/enums";
/**
 * Amazon DataZone projects are business use case–based groupings of people, assets (data), and tools used to simplify access to the AWS analytics.
 */
export declare function getProject(args: GetProjectArgs, opts?: pulumi.InvokeOptions): Promise<GetProjectResult>;
export interface GetProjectArgs {
    /**
     * The identifier of the Amazon DataZone domain in which the project was created.
     */
    domainId: string;
    /**
     * The ID of the Amazon DataZone project.
     */
    id: string;
}
export interface GetProjectResult {
    /**
     * The timestamp of when the project was created.
     */
    readonly createdAt?: string;
    /**
     * The Amazon DataZone user who created the project.
     */
    readonly createdBy?: string;
    /**
     * The description of the Amazon DataZone project.
     */
    readonly description?: string;
    /**
     * The identifier of the Amazon DataZone domain in which the project was created.
     */
    readonly domainId?: string;
    /**
     * The glossary terms that can be used in this Amazon DataZone project.
     */
    readonly glossaryTerms?: string[];
    /**
     * The ID of the Amazon DataZone project.
     */
    readonly id?: string;
    /**
     * The timestamp of when the project was last updated.
     */
    readonly lastUpdatedAt?: string;
    /**
     * The name of the Amazon DataZone project.
     */
    readonly name?: string;
    /**
     * The status of the project.
     */
    readonly projectStatus?: enums.datazone.ProjectStatus;
}
/**
 * Amazon DataZone projects are business use case–based groupings of people, assets (data), and tools used to simplify access to the AWS analytics.
 */
export declare function getProjectOutput(args: GetProjectOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetProjectResult>;
export interface GetProjectOutputArgs {
    /**
     * The identifier of the Amazon DataZone domain in which the project was created.
     */
    domainId: pulumi.Input<string>;
    /**
     * The ID of the Amazon DataZone project.
     */
    id: pulumi.Input<string>;
}
