import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * A owner can set up authorization permissions on their resources.
 */
export declare class Owner extends pulumi.CustomResource {
    /**
     * Get an existing Owner resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): Owner;
    /**
     * Returns true if the given object is an instance of Owner.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Owner;
    /**
     * The ID of the domain in which you want to add the entity owner.
     */
    readonly domainIdentifier: pulumi.Output<string>;
    /**
     * The ID of the entity to which you want to add an owner.
     */
    readonly entityIdentifier: pulumi.Output<string>;
    /**
     * The type of an entity.
     */
    readonly entityType: pulumi.Output<enums.datazone.OwnerEntityType>;
    /**
     * The owner that you want to add to the entity.
     */
    readonly owner: pulumi.Output<outputs.datazone.OwnerProperties>;
    /**
     * Create a Owner resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: OwnerArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a Owner resource.
 */
export interface OwnerArgs {
    /**
     * The ID of the domain in which you want to add the entity owner.
     */
    domainIdentifier: pulumi.Input<string>;
    /**
     * The ID of the entity to which you want to add an owner.
     */
    entityIdentifier: pulumi.Input<string>;
    /**
     * The type of an entity.
     */
    entityType: pulumi.Input<enums.datazone.OwnerEntityType>;
    /**
     * The owner that you want to add to the entity.
     */
    owner: pulumi.Input<inputs.datazone.OwnerPropertiesArgs>;
}
