import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Amazon DataZone projects are business use case–based groupings of people, assets (data), and tools used to simplify access to the AWS analytics.
 */
export declare class Project extends pulumi.CustomResource {
    /**
     * Get an existing Project resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): Project;
    /**
     * Returns true if the given object is an instance of Project.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Project;
    /**
     * The ID of the Amazon DataZone project.
     */
    readonly awsId: pulumi.Output<string>;
    /**
     * The timestamp of when the project was created.
     */
    readonly createdAt: pulumi.Output<string>;
    /**
     * The Amazon DataZone user who created the project.
     */
    readonly createdBy: pulumi.Output<string>;
    /**
     * The description of the Amazon DataZone project.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * The identifier of the Amazon DataZone domain in which the project was created.
     */
    readonly domainId: pulumi.Output<string>;
    /**
     * The ID of the Amazon DataZone domain in which this project is created.
     */
    readonly domainIdentifier: pulumi.Output<string>;
    /**
     * The ID of the domain unit.
     */
    readonly domainUnitId: pulumi.Output<string | undefined>;
    /**
     * The glossary terms that can be used in this Amazon DataZone project.
     */
    readonly glossaryTerms: pulumi.Output<string[] | undefined>;
    /**
     * The timestamp of when the project was last updated.
     */
    readonly lastUpdatedAt: pulumi.Output<string>;
    /**
     * The name of the Amazon DataZone project.
     */
    readonly name: pulumi.Output<string>;
    /**
     * The project profile ID.
     */
    readonly projectProfileId: pulumi.Output<string | undefined>;
    /**
     * The project profile version to which the project should be updated. You can only specify the following string for this parameter: latest.
     */
    readonly projectProfileVersion: pulumi.Output<string | undefined>;
    /**
     * The status of the project.
     */
    readonly projectStatus: pulumi.Output<enums.datazone.ProjectStatus>;
    /**
     * The user parameters of the project.
     */
    readonly userParameters: pulumi.Output<outputs.datazone.ProjectEnvironmentConfigurationUserParameter[] | undefined>;
    /**
     * Create a Project resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: ProjectArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a Project resource.
 */
export interface ProjectArgs {
    /**
     * The description of the Amazon DataZone project.
     */
    description?: pulumi.Input<string>;
    /**
     * The ID of the Amazon DataZone domain in which this project is created.
     */
    domainIdentifier: pulumi.Input<string>;
    /**
     * The ID of the domain unit.
     */
    domainUnitId?: pulumi.Input<string>;
    /**
     * The glossary terms that can be used in this Amazon DataZone project.
     */
    glossaryTerms?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The name of the Amazon DataZone project.
     */
    name?: pulumi.Input<string>;
    /**
     * The project profile ID.
     */
    projectProfileId?: pulumi.Input<string>;
    /**
     * The project profile version to which the project should be updated. You can only specify the following string for this parameter: latest.
     */
    projectProfileVersion?: pulumi.Input<string>;
    /**
     * The user parameters of the project.
     */
    userParameters?: pulumi.Input<pulumi.Input<inputs.datazone.ProjectEnvironmentConfigurationUserParameterArgs>[]>;
}
