import * as pulumi from "@pulumi/pulumi";
/**
 * Specifies the properties for creating a launch template.
 *  The minimum required properties for specifying a launch template are as follows:
 *   +  You must specify at least one property for the launch template data.
 *   +  You can optionally specify a name for the launch template. If you do not specify a name, CFN creates a name for you.
 *
 *  A launch template can contain some or all of the configuration information to launch an instance. When you launch an instance using a launch template, instance properties that are not specified in the launch template use default values, except the ``ImageId`` property, which has no default value. If you do not specify an AMI ID for the launch template ``ImageId`` property, you must specify an AMI ID for the instance ``ImageId`` property.
 *  For more information, see [Launch an instance from a launch template](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ec2-launch-templates.html) in the *Amazon EC2 User Guide*.
 */
export declare function getLaunchTemplate(args: GetLaunchTemplateArgs, opts?: pulumi.InvokeOptions): Promise<GetLaunchTemplateResult>;
export interface GetLaunchTemplateArgs {
    /**
     * The ID of the launch template.
     */
    launchTemplateId: string;
}
export interface GetLaunchTemplateResult {
    /**
     * The default version of the launch template, such as 2.
     *
     * The default version of a launch template cannot be specified in AWS CloudFormation . The default version can be set in the Amazon EC2 console or by using the `modify-launch-template` AWS CLI command.
     */
    readonly defaultVersionNumber?: string;
    /**
     * The latest version of the launch template, such as `5` .
     */
    readonly latestVersionNumber?: string;
    /**
     * The ID of the launch template.
     */
    readonly launchTemplateId?: string;
}
/**
 * Specifies the properties for creating a launch template.
 *  The minimum required properties for specifying a launch template are as follows:
 *   +  You must specify at least one property for the launch template data.
 *   +  You can optionally specify a name for the launch template. If you do not specify a name, CFN creates a name for you.
 *
 *  A launch template can contain some or all of the configuration information to launch an instance. When you launch an instance using a launch template, instance properties that are not specified in the launch template use default values, except the ``ImageId`` property, which has no default value. If you do not specify an AMI ID for the launch template ``ImageId`` property, you must specify an AMI ID for the instance ``ImageId`` property.
 *  For more information, see [Launch an instance from a launch template](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ec2-launch-templates.html) in the *Amazon EC2 User Guide*.
 */
export declare function getLaunchTemplateOutput(args: GetLaunchTemplateOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetLaunchTemplateResult>;
export interface GetLaunchTemplateOutputArgs {
    /**
     * The ID of the launch template.
     */
    launchTemplateId: pulumi.Input<string>;
}
