import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Resource Type definition for AWS::EC2::VPCEndpointService
 */
export declare function getVpcEndpointService(args: GetVpcEndpointServiceArgs, opts?: pulumi.InvokeOptions): Promise<GetVpcEndpointServiceResult>;
export interface GetVpcEndpointServiceArgs {
    /**
     * The ID of the endpoint service.
     */
    serviceId: string;
}
export interface GetVpcEndpointServiceResult {
    /**
     * Indicates whether requests from service consumers to create an endpoint to your service must be accepted.
     */
    readonly acceptanceRequired?: boolean;
    /**
     * The Amazon Resource Names (ARNs) of the Gateway Load Balancers.
     */
    readonly gatewayLoadBalancerArns?: string[];
    /**
     * The Amazon Resource Names (ARNs) of the Network Load Balancers.
     */
    readonly networkLoadBalancerArns?: string[];
    /**
     * The entity that is responsible for the endpoint costs. The default is the endpoint owner. If you set the payer responsibility to the service owner, you cannot set it back to the endpoint owner.
     */
    readonly payerResponsibility?: string;
    /**
     * The ID of the endpoint service.
     */
    readonly serviceId?: string;
    /**
     * Specify which Ip Address types are supported for VPC endpoint service.
     */
    readonly supportedIpAddressTypes?: enums.ec2.VpcEndpointServiceIpAddressType[];
    /**
     * The Regions from which service consumers can access the service.
     */
    readonly supportedRegions?: string[];
    /**
     * The tags to add to the VPC endpoint service.
     */
    readonly tags?: outputs.Tag[];
}
/**
 * Resource Type definition for AWS::EC2::VPCEndpointService
 */
export declare function getVpcEndpointServiceOutput(args: GetVpcEndpointServiceOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetVpcEndpointServiceResult>;
export interface GetVpcEndpointServiceOutputArgs {
    /**
     * The ID of the endpoint service.
     */
    serviceId: pulumi.Input<string>;
}
