import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * The ``AWS::ECR::ReplicationConfiguration`` resource creates or updates the replication configuration for a private registry. The first time a replication configuration is applied to a private registry, a service-linked IAM role is created in your account for the replication process. For more information, see [Using Service-Linked Roles for Amazon ECR](https://docs.aws.amazon.com/AmazonECR/latest/userguide/using-service-linked-roles.html) in the *Amazon Elastic Container Registry User Guide*.
 *   When configuring cross-account replication, the destination account must grant the source account permission to replicate. This permission is controlled using a private registry permissions policy. For more information, see ``AWS::ECR::RegistryPolicy``.
 */
export declare function getReplicationConfiguration(args: GetReplicationConfigurationArgs, opts?: pulumi.InvokeOptions): Promise<GetReplicationConfigurationResult>;
export interface GetReplicationConfigurationArgs {
    /**
     * The account ID of the destination registry.
     */
    registryId: string;
}
export interface GetReplicationConfigurationResult {
    /**
     * The account ID of the destination registry.
     */
    readonly registryId?: string;
    /**
     * The replication configuration for a registry.
     */
    readonly replicationConfiguration?: outputs.ecr.ReplicationConfiguration;
}
/**
 * The ``AWS::ECR::ReplicationConfiguration`` resource creates or updates the replication configuration for a private registry. The first time a replication configuration is applied to a private registry, a service-linked IAM role is created in your account for the replication process. For more information, see [Using Service-Linked Roles for Amazon ECR](https://docs.aws.amazon.com/AmazonECR/latest/userguide/using-service-linked-roles.html) in the *Amazon Elastic Container Registry User Guide*.
 *   When configuring cross-account replication, the destination account must grant the source account permission to replicate. This permission is controlled using a private registry permissions policy. For more information, see ``AWS::ECR::RegistryPolicy``.
 */
export declare function getReplicationConfigurationOutput(args: GetReplicationConfigurationOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetReplicationConfigurationResult>;
export interface GetReplicationConfigurationOutputArgs {
    /**
     * The account ID of the destination registry.
     */
    registryId: pulumi.Input<string>;
}
