import * as pulumi from "@pulumi/pulumi";
import * as enums from "../types/enums";
/**
 * An example resource schema demonstrating some basic constructs and validation rules.
 */
export declare function getStudioSessionMapping(args: GetStudioSessionMappingArgs, opts?: pulumi.InvokeOptions): Promise<GetStudioSessionMappingResult>;
export interface GetStudioSessionMappingArgs {
    /**
     * The name of the user or group. For more information, see UserName and DisplayName in the AWS SSO Identity Store API Reference. Either IdentityName or IdentityId must be specified.
     */
    identityName: string;
    /**
     * Specifies whether the identity to map to the Studio is a user or a group.
     */
    identityType: enums.emr.StudioSessionMappingIdentityType;
    /**
     * The ID of the Amazon EMR Studio to which the user or group will be mapped.
     */
    studioId: string;
}
export interface GetStudioSessionMappingResult {
    /**
     * The Amazon Resource Name (ARN) for the session policy that will be applied to the user or group. Session policies refine Studio user permissions without the need to use multiple IAM user roles.
     */
    readonly sessionPolicyArn?: string;
}
/**
 * An example resource schema demonstrating some basic constructs and validation rules.
 */
export declare function getStudioSessionMappingOutput(args: GetStudioSessionMappingOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetStudioSessionMappingResult>;
export interface GetStudioSessionMappingOutputArgs {
    /**
     * The name of the user or group. For more information, see UserName and DisplayName in the AWS SSO Identity Store API Reference. Either IdentityName or IdentityId must be specified.
     */
    identityName: pulumi.Input<string>;
    /**
     * Specifies whether the identity to map to the Studio is a user or a group.
     */
    identityType: pulumi.Input<enums.emr.StudioSessionMappingIdentityType>;
    /**
     * The ID of the Amazon EMR Studio to which the user or group will be mapped.
     */
    studioId: pulumi.Input<string>;
}
