import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Represents a dataset group that holds a collection of related datasets
 */
export declare class DatasetGroup extends pulumi.CustomResource {
    /**
     * Get an existing DatasetGroup resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): DatasetGroup;
    /**
     * Returns true if the given object is an instance of DatasetGroup.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is DatasetGroup;
    /**
     * An array of Amazon Resource Names (ARNs) of the datasets that you want to include in the dataset group.
     */
    readonly datasetArns: pulumi.Output<string[] | undefined>;
    /**
     * The Amazon Resource Name (ARN) of the dataset group to delete.
     */
    readonly datasetGroupArn: pulumi.Output<string>;
    /**
     * A name for the dataset group.
     */
    readonly datasetGroupName: pulumi.Output<string>;
    /**
     * The domain associated with the dataset group. When you add a dataset to a dataset group, this value and the value specified for the Domain parameter of the CreateDataset operation must match.
     */
    readonly domain: pulumi.Output<enums.forecast.DatasetGroupDomain>;
    /**
     * The tags of Application Insights application.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Create a DatasetGroup resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: DatasetGroupArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a DatasetGroup resource.
 */
export interface DatasetGroupArgs {
    /**
     * An array of Amazon Resource Names (ARNs) of the datasets that you want to include in the dataset group.
     */
    datasetArns?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * A name for the dataset group.
     */
    datasetGroupName?: pulumi.Input<string>;
    /**
     * The domain associated with the dataset group. When you add a dataset to a dataset group, this value and the value specified for the Domain parameter of the CreateDataset operation must match.
     */
    domain: pulumi.Input<enums.forecast.DatasetGroupDomain>;
    /**
     * The tags of Application Insights application.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
