import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Resource schema for AWS::ImageBuilder::ImagePipeline
 */
export declare function getImagePipeline(args: GetImagePipelineArgs, opts?: pulumi.InvokeOptions): Promise<GetImagePipelineResult>;
export interface GetImagePipelineArgs {
    /**
     * The Amazon Resource Name (ARN) of the image pipeline.
     */
    arn: string;
}
export interface GetImagePipelineResult {
    /**
     * The Amazon Resource Name (ARN) of the image pipeline.
     */
    readonly arn?: string;
    /**
     * The Amazon Resource Name (ARN) of the container recipe that defines how images are configured and tested.
     */
    readonly containerRecipeArn?: string;
    /**
     * The description of the image pipeline.
     */
    readonly description?: string;
    /**
     * The Amazon Resource Name (ARN) of the distribution configuration associated with this image pipeline.
     */
    readonly distributionConfigurationArn?: string;
    /**
     * Collects additional information about the image being created, including the operating system (OS) version and package list.
     */
    readonly enhancedImageMetadataEnabled?: boolean;
    /**
     * The execution role name/ARN for the image build, if provided
     */
    readonly executionRole?: string;
    /**
     * The Amazon Resource Name (ARN) of the image recipe that defines how images are configured, tested, and assessed.
     */
    readonly imageRecipeArn?: string;
    /**
     * Contains settings for vulnerability scans.
     */
    readonly imageScanningConfiguration?: outputs.imagebuilder.ImagePipelineImageScanningConfiguration;
    /**
     * The image tests configuration of the image pipeline.
     */
    readonly imageTestsConfiguration?: outputs.imagebuilder.ImagePipelineImageTestsConfiguration;
    /**
     * The Amazon Resource Name (ARN) of the infrastructure configuration associated with this image pipeline.
     */
    readonly infrastructureConfigurationArn?: string;
    /**
     * The schedule of the image pipeline.
     */
    readonly schedule?: outputs.imagebuilder.ImagePipelineSchedule;
    /**
     * The status of the image pipeline.
     */
    readonly status?: enums.imagebuilder.ImagePipelineStatus;
    /**
     * The tags of this image pipeline.
     */
    readonly tags?: {
        [key: string]: string;
    };
    /**
     * Workflows to define the image build process
     */
    readonly workflows?: outputs.imagebuilder.ImagePipelineWorkflowConfiguration[];
}
/**
 * Resource schema for AWS::ImageBuilder::ImagePipeline
 */
export declare function getImagePipelineOutput(args: GetImagePipelineOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetImagePipelineResult>;
export interface GetImagePipelineOutputArgs {
    /**
     * The Amazon Resource Name (ARN) of the image pipeline.
     */
    arn: pulumi.Input<string>;
}
