import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * CIS Scan Configuration resource schema
 */
export declare class CisScanConfiguration extends pulumi.CustomResource {
    /**
     * Get an existing CisScanConfiguration resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): CisScanConfiguration;
    /**
     * Returns true if the given object is an instance of CisScanConfiguration.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is CisScanConfiguration;
    /**
     * CIS Scan configuration unique identifier
     */
    readonly arn: pulumi.Output<string>;
    /**
     * Name of the scan
     */
    readonly scanName: pulumi.Output<string>;
    /**
     * The CIS scan configuration's schedule.
     */
    readonly schedule: pulumi.Output<outputs.inspectorv2.CisScanConfigurationSchedule>;
    /**
     * The CIS scan configuration's CIS Benchmark level.
     */
    readonly securityLevel: pulumi.Output<enums.inspectorv2.CisScanConfigurationCisSecurityLevel>;
    /**
     * The CIS scan configuration's tags.
     */
    readonly tags: pulumi.Output<{
        [key: string]: string;
    } | undefined>;
    /**
     * The CIS scan configuration's targets.
     */
    readonly targets: pulumi.Output<outputs.inspectorv2.CisScanConfigurationCisTargets>;
    /**
     * Create a CisScanConfiguration resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: CisScanConfigurationArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a CisScanConfiguration resource.
 */
export interface CisScanConfigurationArgs {
    /**
     * Name of the scan
     */
    scanName: pulumi.Input<string>;
    /**
     * The CIS scan configuration's schedule.
     */
    schedule: pulumi.Input<inputs.inspectorv2.CisScanConfigurationScheduleArgs>;
    /**
     * The CIS scan configuration's CIS Benchmark level.
     */
    securityLevel: pulumi.Input<enums.inspectorv2.CisScanConfigurationCisSecurityLevel>;
    /**
     * The CIS scan configuration's tags.
     */
    tags?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
    /**
     * The CIS scan configuration's targets.
     */
    targets: pulumi.Input<inputs.inspectorv2.CisScanConfigurationCisTargetsArgs>;
}
