import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Represents the resource definition of AWS IoT Command.
 */
export declare class Command extends pulumi.CustomResource {
    /**
     * Get an existing Command resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): Command;
    /**
     * Returns true if the given object is an instance of Command.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Command;
    /**
     * The Amazon Resource Name (ARN) of the command.
     */
    readonly commandArn: pulumi.Output<string>;
    /**
     * The unique identifier for the command.
     */
    readonly commandId: pulumi.Output<string>;
    /**
     * The date and time when the command was created.
     */
    readonly createdAt: pulumi.Output<string | undefined>;
    /**
     * A flag indicating whether the command is deprecated.
     */
    readonly deprecated: pulumi.Output<boolean | undefined>;
    /**
     * The description of the command.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * The display name for the command.
     */
    readonly displayName: pulumi.Output<string | undefined>;
    /**
     * The date and time when the command was last updated.
     */
    readonly lastUpdatedAt: pulumi.Output<string | undefined>;
    /**
     * The list of mandatory parameters for the command.
     */
    readonly mandatoryParameters: pulumi.Output<outputs.iot.CommandParameter[] | undefined>;
    /**
     * The namespace to which the command belongs.
     */
    readonly namespace: pulumi.Output<enums.iot.CommandNamespace | undefined>;
    /**
     * The payload associated with the command.
     */
    readonly payload: pulumi.Output<outputs.iot.CommandPayload | undefined>;
    /**
     * A flag indicating whether the command is pending deletion.
     */
    readonly pendingDeletion: pulumi.Output<boolean | undefined>;
    /**
     * The customer role associated with the command.
     */
    readonly roleArn: pulumi.Output<string | undefined>;
    /**
     * The tags to be associated with the command.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Create a Command resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: CommandArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a Command resource.
 */
export interface CommandArgs {
    /**
     * The unique identifier for the command.
     */
    commandId: pulumi.Input<string>;
    /**
     * The date and time when the command was created.
     */
    createdAt?: pulumi.Input<string>;
    /**
     * A flag indicating whether the command is deprecated.
     */
    deprecated?: pulumi.Input<boolean>;
    /**
     * The description of the command.
     */
    description?: pulumi.Input<string>;
    /**
     * The display name for the command.
     */
    displayName?: pulumi.Input<string>;
    /**
     * The date and time when the command was last updated.
     */
    lastUpdatedAt?: pulumi.Input<string>;
    /**
     * The list of mandatory parameters for the command.
     */
    mandatoryParameters?: pulumi.Input<pulumi.Input<inputs.iot.CommandParameterArgs>[]>;
    /**
     * The namespace to which the command belongs.
     */
    namespace?: pulumi.Input<enums.iot.CommandNamespace>;
    /**
     * The payload associated with the command.
     */
    payload?: pulumi.Input<inputs.iot.CommandPayloadArgs>;
    /**
     * A flag indicating whether the command is pending deletion.
     */
    pendingDeletion?: pulumi.Input<boolean>;
    /**
     * The customer role associated with the command.
     */
    roleArn?: pulumi.Input<string>;
    /**
     * The tags to be associated with the command.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
