import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * resource definition
 */
export declare class SoftwarePackageVersion extends pulumi.CustomResource {
    /**
     * Get an existing SoftwarePackageVersion resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): SoftwarePackageVersion;
    /**
     * Returns true if the given object is an instance of SoftwarePackageVersion.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is SoftwarePackageVersion;
    readonly artifact: pulumi.Output<outputs.iot.SoftwarePackageVersionPackageVersionArtifact | undefined>;
    /**
     * Metadata that can be used to define a package version’s configuration. For example, the S3 file location, configuration options that are being sent to the device or fleet.
     *
     * The combined size of all the attributes on a package version is limited to 3KB.
     */
    readonly attributes: pulumi.Output<{
        [key: string]: string;
    } | undefined>;
    /**
     * A summary of the package version being created. This can be used to outline the package's contents or purpose.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * Error reason for a package version failure during creation or update.
     */
    readonly errorReason: pulumi.Output<string>;
    /**
     * The name of the associated software package.
     */
    readonly packageName: pulumi.Output<string>;
    /**
     * The Amazon Resource Name (ARN) for the package.
     */
    readonly packageVersionArn: pulumi.Output<string>;
    /**
     * The inline json job document associated with a software package version
     */
    readonly recipe: pulumi.Output<string | undefined>;
    readonly sbom: pulumi.Output<outputs.iot.SoftwarePackageVersionSbom | undefined>;
    readonly sbomValidationStatus: pulumi.Output<enums.iot.SoftwarePackageVersionSbomValidationStatus>;
    /**
     * The status of the package version. For more information, see [Package version lifecycle](https://docs.aws.amazon.com/iot/latest/developerguide/preparing-to-use-software-package-catalog.html#package-version-lifecycle) .
     */
    readonly status: pulumi.Output<enums.iot.SoftwarePackageVersionPackageVersionStatus>;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * The name of the new package version.
     */
    readonly versionName: pulumi.Output<string | undefined>;
    /**
     * Create a SoftwarePackageVersion resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: SoftwarePackageVersionArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a SoftwarePackageVersion resource.
 */
export interface SoftwarePackageVersionArgs {
    artifact?: pulumi.Input<inputs.iot.SoftwarePackageVersionPackageVersionArtifactArgs>;
    /**
     * Metadata that can be used to define a package version’s configuration. For example, the S3 file location, configuration options that are being sent to the device or fleet.
     *
     * The combined size of all the attributes on a package version is limited to 3KB.
     */
    attributes?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
    /**
     * A summary of the package version being created. This can be used to outline the package's contents or purpose.
     */
    description?: pulumi.Input<string>;
    /**
     * The name of the associated software package.
     */
    packageName: pulumi.Input<string>;
    /**
     * The inline json job document associated with a software package version
     */
    recipe?: pulumi.Input<string>;
    sbom?: pulumi.Input<inputs.iot.SoftwarePackageVersionSbomArgs>;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
    /**
     * The name of the new package version.
     */
    versionName?: pulumi.Input<string>;
}
