import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Resource Type definition for AWS::IoT::Thing
 *
 * ## Example Usage
 * ### Example
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws_native from "@pulumi/aws-native";
 *
 * const config = new pulumi.Config();
 * const nameParameter = config.require("nameParameter");
 * const myAttributeValueA = config.get("myAttributeValueA") || "myStringA123";
 * const myAttributeValueB = config.get("myAttributeValueB") || "myStringB123";
 * const myAttributeValueC = config.get("myAttributeValueC") || "myStringC123";
 * const myThing = new aws_native.iot.Thing("myThing", {
 *     thingName: nameParameter,
 *     attributePayload: {
 *         attributes: {
 *             myAttributeA: myAttributeValueA,
 *             myAttributeB: myAttributeValueB,
 *             myAttributeC: myAttributeValueC,
 *         },
 *     },
 * });
 *
 * ```
 */
export declare class Thing extends pulumi.CustomResource {
    /**
     * Get an existing Thing resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): Thing;
    /**
     * Returns true if the given object is an instance of Thing.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Thing;
    /**
     * The Amazon Resource Name (ARN) of the AWS IoT thing, such as `arn:aws:iot:us-east-2:123456789012:thing/MyThing` .
     */
    readonly arn: pulumi.Output<string>;
    /**
     * A string that contains up to three key value pairs. Maximum length of 800. Duplicates not allowed.
     */
    readonly attributePayload: pulumi.Output<outputs.iot.ThingAttributePayload | undefined>;
    /**
     * The Id of this thing.
     */
    readonly awsId: pulumi.Output<string>;
    /**
     * The name of the thing to update.
     *
     * You can't change a thing's name. To change a thing's name, you must create a new thing, give it the new name, and then delete the old thing.
     */
    readonly thingName: pulumi.Output<string | undefined>;
    /**
     * Create a Thing resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: ThingArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a Thing resource.
 */
export interface ThingArgs {
    /**
     * A string that contains up to three key value pairs. Maximum length of 800. Duplicates not allowed.
     */
    attributePayload?: pulumi.Input<inputs.iot.ThingAttributePayloadArgs>;
    /**
     * The name of the thing to update.
     *
     * You can't change a thing's name. To change a thing's name, you must create a new thing, give it the new name, and then delete the old thing.
     */
    thingName?: pulumi.Input<string>;
}
