import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Resource schema for AWS::IoTSiteWise::Portal
 */
export declare class Portal extends pulumi.CustomResource {
    /**
     * Get an existing Portal resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): Portal;
    /**
     * Returns true if the given object is an instance of Portal.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Portal;
    /**
     * Contains the configuration information of an alarm created in an AWS IoT SiteWise Monitor portal. You can use the alarm to monitor an asset property and get notified when the asset property value is outside a specified range.
     */
    readonly alarms: pulumi.Output<outputs.iotsitewise.AlarmsProperties | undefined>;
    /**
     * The email address that sends alarm notifications.
     */
    readonly notificationSenderEmail: pulumi.Output<string | undefined>;
    /**
     * The ARN of the portal, which has the following format.
     */
    readonly portalArn: pulumi.Output<string>;
    /**
     * The service to use to authenticate users to the portal. Choose from SSO or IAM. You can't change this value after you create a portal.
     */
    readonly portalAuthMode: pulumi.Output<string | undefined>;
    /**
     * The AWS SSO application generated client ID (used with AWS SSO APIs).
     */
    readonly portalClientId: pulumi.Output<string>;
    /**
     * The AWS administrator's contact email address.
     */
    readonly portalContactEmail: pulumi.Output<string>;
    /**
     * A description for the portal.
     */
    readonly portalDescription: pulumi.Output<string | undefined>;
    /**
     * The ID of the portal.
     */
    readonly portalId: pulumi.Output<string>;
    /**
     * A friendly name for the portal.
     */
    readonly portalName: pulumi.Output<string>;
    /**
     * The public root URL for the AWS IoT AWS IoT SiteWise Monitor application portal.
     */
    readonly portalStartUrl: pulumi.Output<string>;
    /**
     * The type of portal
     */
    readonly portalType: pulumi.Output<enums.iotsitewise.PortalType | undefined>;
    readonly portalTypeConfiguration: pulumi.Output<{
        [key: string]: outputs.iotsitewise.PortalTypeEntry;
    } | undefined>;
    /**
     * The ARN of a service role that allows the portal's users to access your AWS IoT SiteWise resources on your behalf.
     */
    readonly roleArn: pulumi.Output<string>;
    /**
     * A list of key-value pairs that contain metadata for the portal.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Create a Portal resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: PortalArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a Portal resource.
 */
export interface PortalArgs {
    /**
     * Contains the configuration information of an alarm created in an AWS IoT SiteWise Monitor portal. You can use the alarm to monitor an asset property and get notified when the asset property value is outside a specified range.
     */
    alarms?: pulumi.Input<inputs.iotsitewise.AlarmsPropertiesArgs>;
    /**
     * The email address that sends alarm notifications.
     */
    notificationSenderEmail?: pulumi.Input<string>;
    /**
     * The service to use to authenticate users to the portal. Choose from SSO or IAM. You can't change this value after you create a portal.
     */
    portalAuthMode?: pulumi.Input<string>;
    /**
     * The AWS administrator's contact email address.
     */
    portalContactEmail: pulumi.Input<string>;
    /**
     * A description for the portal.
     */
    portalDescription?: pulumi.Input<string>;
    /**
     * A friendly name for the portal.
     */
    portalName?: pulumi.Input<string>;
    /**
     * The type of portal
     */
    portalType?: pulumi.Input<enums.iotsitewise.PortalType>;
    portalTypeConfiguration?: pulumi.Input<{
        [key: string]: pulumi.Input<inputs.iotsitewise.PortalTypeEntryArgs>;
    }>;
    /**
     * The ARN of a service role that allows the portal's users to access your AWS IoT SiteWise resources on your behalf.
     */
    roleArn: pulumi.Input<string>;
    /**
     * A list of key-value pairs that contain metadata for the portal.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
