import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * Resource type definition for AWS::IVSChat::Room.
 */
export declare function getRoom(args: GetRoomArgs, opts?: pulumi.InvokeOptions): Promise<GetRoomResult>;
export interface GetRoomArgs {
    /**
     * Room ARN is automatically generated on creation and assigned as the unique identifier.
     */
    arn: string;
}
export interface GetRoomResult {
    /**
     * Room ARN is automatically generated on creation and assigned as the unique identifier.
     */
    readonly arn?: string;
    /**
     * The system-generated ID of the room.
     */
    readonly id?: string;
    /**
     * Array of logging configuration identifiers attached to the room.
     */
    readonly loggingConfigurationIdentifiers?: string[];
    /**
     * The maximum number of characters in a single message.
     */
    readonly maximumMessageLength?: number;
    /**
     * The maximum number of messages per second that can be sent to the room.
     */
    readonly maximumMessageRatePerSecond?: number;
    /**
     * Configuration information for optional review of messages.
     */
    readonly messageReviewHandler?: outputs.ivschat.RoomMessageReviewHandler;
    /**
     * The name of the room. The value does not need to be unique.
     */
    readonly name?: string;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    readonly tags?: outputs.Tag[];
}
/**
 * Resource type definition for AWS::IVSChat::Room.
 */
export declare function getRoomOutput(args: GetRoomOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetRoomResult>;
export interface GetRoomOutputArgs {
    /**
     * Room ARN is automatically generated on creation and assigned as the unique identifier.
     */
    arn: pulumi.Input<string>;
}
