import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Creates an Amazon Kinesis Data Analytics application. For information about creating a Kinesis Data Analytics application, see [Creating an Application](https://docs.aws.amazon.com/kinesisanalytics/latest/java/getting-started.html).
 */
export declare class Application extends pulumi.CustomResource {
    /**
     * Get an existing Application resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): Application;
    /**
     * Returns true if the given object is an instance of Application.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Application;
    /**
     * Use this parameter to configure the application.
     */
    readonly applicationConfiguration: pulumi.Output<outputs.kinesisanalyticsv2.ApplicationConfiguration | undefined>;
    /**
     * The description of the application.
     */
    readonly applicationDescription: pulumi.Output<string | undefined>;
    /**
     * Used to configure start of maintenance window.
     */
    readonly applicationMaintenanceConfiguration: pulumi.Output<outputs.kinesisanalyticsv2.ApplicationMaintenanceConfiguration | undefined>;
    /**
     * To create a Kinesis Data Analytics Studio notebook, you must set the mode to `INTERACTIVE`. However, for a Kinesis Data Analytics for Apache Flink application, the mode is optional.
     */
    readonly applicationMode: pulumi.Output<enums.kinesisanalyticsv2.ApplicationMode | undefined>;
    /**
     * The name of the application.
     */
    readonly applicationName: pulumi.Output<string | undefined>;
    /**
     * Specifies run configuration (start parameters) of a Kinesis Data Analytics application. Evaluated on update for RUNNING applications an only.
     */
    readonly runConfiguration: pulumi.Output<outputs.kinesisanalyticsv2.ApplicationRunConfiguration | undefined>;
    /**
     * The runtime environment for the application.
     */
    readonly runtimeEnvironment: pulumi.Output<string>;
    /**
     * Specifies the IAM role that the application uses to access external resources.
     */
    readonly serviceExecutionRole: pulumi.Output<string>;
    /**
     * A list of one or more tags to assign to the application. A tag is a key-value pair that identifies an application. Note that the maximum number of application tags includes system tags. The maximum number of user-defined application tags is 50.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Create a Application resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: ApplicationArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a Application resource.
 */
export interface ApplicationArgs {
    /**
     * Use this parameter to configure the application.
     */
    applicationConfiguration?: pulumi.Input<inputs.kinesisanalyticsv2.ApplicationConfigurationArgs>;
    /**
     * The description of the application.
     */
    applicationDescription?: pulumi.Input<string>;
    /**
     * Used to configure start of maintenance window.
     */
    applicationMaintenanceConfiguration?: pulumi.Input<inputs.kinesisanalyticsv2.ApplicationMaintenanceConfigurationArgs>;
    /**
     * To create a Kinesis Data Analytics Studio notebook, you must set the mode to `INTERACTIVE`. However, for a Kinesis Data Analytics for Apache Flink application, the mode is optional.
     */
    applicationMode?: pulumi.Input<enums.kinesisanalyticsv2.ApplicationMode>;
    /**
     * The name of the application.
     */
    applicationName?: pulumi.Input<string>;
    /**
     * Specifies run configuration (start parameters) of a Kinesis Data Analytics application. Evaluated on update for RUNNING applications an only.
     */
    runConfiguration?: pulumi.Input<inputs.kinesisanalyticsv2.ApplicationRunConfigurationArgs>;
    /**
     * The runtime environment for the application.
     */
    runtimeEnvironment: pulumi.Input<string>;
    /**
     * Specifies the IAM role that the application uses to access external resources.
     */
    serviceExecutionRole: pulumi.Input<string>;
    /**
     * A list of one or more tags to assign to the application. A tag is a key-value pair that identifies an application. Note that the maximum number of application tags includes system tags. The maximum number of user-defined application tags is 50.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
