import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Resource Type Definition for AWS::KinesisVideo::SignalingChannel
 */
export declare class SignalingChannel extends pulumi.CustomResource {
    /**
     * Get an existing SignalingChannel resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): SignalingChannel;
    /**
     * Returns true if the given object is an instance of SignalingChannel.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is SignalingChannel;
    /**
     * The Amazon Resource Name (ARN) of the Kinesis Video Signaling Channel.
     */
    readonly arn: pulumi.Output<string>;
    /**
     * The period of time a signaling channel retains undelivered messages before they are discarded.
     */
    readonly messageTtlSeconds: pulumi.Output<number | undefined>;
    /**
     * The name of the Kinesis Video Signaling Channel.
     */
    readonly name: pulumi.Output<string | undefined>;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * The type of the Kinesis Video Signaling Channel to create. Currently, SINGLE_MASTER is the only supported channel type.
     */
    readonly type: pulumi.Output<enums.kinesisvideo.SignalingChannelType | undefined>;
    /**
     * Create a SignalingChannel resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: SignalingChannelArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a SignalingChannel resource.
 */
export interface SignalingChannelArgs {
    /**
     * The period of time a signaling channel retains undelivered messages before they are discarded.
     */
    messageTtlSeconds?: pulumi.Input<number>;
    /**
     * The name of the Kinesis Video Signaling Channel.
     */
    name?: pulumi.Input<string>;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
    /**
     * The type of the Kinesis Video Signaling Channel to create. Currently, SINGLE_MASTER is the only supported channel type.
     */
    type?: pulumi.Input<enums.kinesisvideo.SignalingChannelType>;
}
