import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * This structure contains information about one delivery in your account.
 *
 * A delivery is a connection between a logical delivery source and a logical delivery destination.
 *
 * For more information, see [CreateDelivery](https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_CreateDelivery.html).
 */
export declare function getDelivery(args: GetDeliveryArgs, opts?: pulumi.InvokeOptions): Promise<GetDeliveryResult>;
export interface GetDeliveryArgs {
    /**
     * The unique ID that identifies this delivery in your account.
     */
    deliveryId: string;
}
export interface GetDeliveryResult {
    /**
     * The Amazon Resource Name (ARN) that uniquely identifies this delivery.
     */
    readonly arn?: string;
    /**
     * Displays whether the delivery destination associated with this delivery is CloudWatch Logs, Amazon S3, or Kinesis Data Firehose.
     */
    readonly deliveryDestinationType?: string;
    /**
     * The unique ID that identifies this delivery in your account.
     */
    readonly deliveryId?: string;
    /**
     * The field delimiter to use between record fields when the final output format of a delivery is in Plain , W3C , or Raw format.
     */
    readonly fieldDelimiter?: string;
    /**
     * The list of record fields to be delivered to the destination, in order. If the delivery's log source has mandatory fields, they must be included in this list.
     */
    readonly recordFields?: string[];
    /**
     * This parameter causes the S3 objects that contain delivered logs to use a prefix structure that allows for integration with Apache Hive.
     */
    readonly s3EnableHiveCompatiblePath?: boolean;
    /**
     * This string allows re-configuring the S3 object prefix to contain either static or variable sections. The valid variables to use in the suffix path will vary by each log source. See ConfigurationTemplate$allowedSuffixPathFields for more info on what values are supported in the suffix path for each log source.
     */
    readonly s3SuffixPath?: string;
    /**
     * The tags that have been assigned to this delivery.
     */
    readonly tags?: outputs.Tag[];
}
/**
 * This structure contains information about one delivery in your account.
 *
 * A delivery is a connection between a logical delivery source and a logical delivery destination.
 *
 * For more information, see [CreateDelivery](https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_CreateDelivery.html).
 */
export declare function getDeliveryOutput(args: GetDeliveryOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetDeliveryResult>;
export interface GetDeliveryOutputArgs {
    /**
     * The unique ID that identifies this delivery in your account.
     */
    deliveryId: pulumi.Input<string>;
}
