import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * <p>Represents an origin endpoint that is associated with a channel, offering a dynamically repackaged version of its content through various streaming media protocols. The content can be efficiently disseminated to end-users via a Content Delivery Network (CDN), like Amazon CloudFront.</p>
 */
export declare function getOriginEndpoint(args: GetOriginEndpointArgs, opts?: pulumi.InvokeOptions): Promise<GetOriginEndpointResult>;
export interface GetOriginEndpointArgs {
    /**
     * <p>The Amazon Resource Name (ARN) associated with the resource.</p>
     */
    arn: string;
}
export interface GetOriginEndpointResult {
    /**
     * <p>The Amazon Resource Name (ARN) associated with the resource.</p>
     */
    readonly arn?: string;
    /**
     * The container type associated with the origin endpoint configuration.
     */
    readonly containerType?: enums.mediapackagev2.OriginEndpointContainerType;
    /**
     * <p>The date and time the origin endpoint was created.</p>
     */
    readonly createdAt?: string;
    readonly dashManifestUrls?: string[];
    /**
     * <p>A DASH manifest configuration.</p>
     */
    readonly dashManifests?: outputs.mediapackagev2.OriginEndpointDashManifestConfiguration[];
    /**
     * <p>Enter any descriptive text that helps you to identify the origin endpoint.</p>
     */
    readonly description?: string;
    /**
     * The failover settings for the endpoint.
     */
    readonly forceEndpointErrorConfiguration?: outputs.mediapackagev2.OriginEndpointForceEndpointErrorConfiguration;
    readonly hlsManifestUrls?: string[];
    /**
     * <p>An HTTP live streaming (HLS) manifest configuration.</p>
     */
    readonly hlsManifests?: outputs.mediapackagev2.OriginEndpointHlsManifestConfiguration[];
    readonly lowLatencyHlsManifestUrls?: string[];
    /**
     * <p>A low-latency HLS manifest configuration.</p>
     */
    readonly lowLatencyHlsManifests?: outputs.mediapackagev2.OriginEndpointLowLatencyHlsManifestConfiguration[];
    /**
     * <p>The date and time the origin endpoint was modified.</p>
     */
    readonly modifiedAt?: string;
    /**
     * The segment associated with the origin endpoint.
     */
    readonly segment?: outputs.mediapackagev2.OriginEndpointSegment;
    /**
     * <p>The size of the window (in seconds) to create a window of the live stream that's available for on-demand viewing. Viewers can start-over or catch-up on content that falls within the window. The maximum startover window is 1,209,600 seconds (14 days).</p>
     */
    readonly startoverWindowSeconds?: number;
    /**
     * The tags associated with the origin endpoint.
     */
    readonly tags?: outputs.Tag[];
}
/**
 * <p>Represents an origin endpoint that is associated with a channel, offering a dynamically repackaged version of its content through various streaming media protocols. The content can be efficiently disseminated to end-users via a Content Delivery Network (CDN), like Amazon CloudFront.</p>
 */
export declare function getOriginEndpointOutput(args: GetOriginEndpointOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetOriginEndpointResult>;
export interface GetOriginEndpointOutputArgs {
    /**
     * <p>The Amazon Resource Name (ARN) associated with the resource.</p>
     */
    arn: pulumi.Input<string>;
}
