import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Resource Type definition for AWS::MSK::Cluster
 */
export declare class Cluster extends pulumi.CustomResource {
    /**
     * Get an existing Cluster resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): Cluster;
    /**
     * Returns true if the given object is an instance of Cluster.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Cluster;
    /**
     * The Amazon Resource Name (ARN) of the MSK cluster.
     */
    readonly arn: pulumi.Output<string>;
    /**
     * Information about the broker nodes in the cluster.
     */
    readonly brokerNodeGroupInfo: pulumi.Output<outputs.msk.ClusterBrokerNodeGroupInfo>;
    /**
     * Includes all client authentication related information.
     */
    readonly clientAuthentication: pulumi.Output<outputs.msk.ClusterClientAuthentication | undefined>;
    /**
     * The name of the cluster.
     */
    readonly clusterName: pulumi.Output<string>;
    /**
     * Represents the configuration that you want MSK to use for the cluster.
     */
    readonly configurationInfo: pulumi.Output<outputs.msk.ClusterConfigurationInfo | undefined>;
    /**
     * The current version of the MSK cluster
     */
    readonly currentVersion: pulumi.Output<string | undefined>;
    /**
     * Includes all encryption-related information.
     */
    readonly encryptionInfo: pulumi.Output<outputs.msk.ClusterEncryptionInfo | undefined>;
    /**
     * Specifies the level of monitoring for the MSK cluster.
     */
    readonly enhancedMonitoring: pulumi.Output<enums.msk.ClusterEnhancedMonitoring | undefined>;
    /**
     * The version of Apache Kafka. You can use Amazon MSK to create clusters that use [supported Apache Kafka versions](https://docs.aws.amazon.com/msk/latest/developerguide/supported-kafka-versions.html) .
     */
    readonly kafkaVersion: pulumi.Output<string>;
    /**
     * Logging info details for the cluster.
     */
    readonly loggingInfo: pulumi.Output<outputs.msk.ClusterLoggingInfo | undefined>;
    /**
     * The number of broker nodes in the cluster.
     */
    readonly numberOfBrokerNodes: pulumi.Output<number>;
    /**
     * The settings for open monitoring.
     */
    readonly openMonitoring: pulumi.Output<outputs.msk.ClusterOpenMonitoring | undefined>;
    /**
     * This controls storage mode for supported storage tiers.
     */
    readonly storageMode: pulumi.Output<enums.msk.ClusterStorageMode | undefined>;
    /**
     * A key-value pair to associate with a resource.
     */
    readonly tags: pulumi.Output<{
        [key: string]: string;
    } | undefined>;
    /**
     * Create a Cluster resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: ClusterArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a Cluster resource.
 */
export interface ClusterArgs {
    /**
     * Information about the broker nodes in the cluster.
     */
    brokerNodeGroupInfo: pulumi.Input<inputs.msk.ClusterBrokerNodeGroupInfoArgs>;
    /**
     * Includes all client authentication related information.
     */
    clientAuthentication?: pulumi.Input<inputs.msk.ClusterClientAuthenticationArgs>;
    /**
     * The name of the cluster.
     */
    clusterName?: pulumi.Input<string>;
    /**
     * Represents the configuration that you want MSK to use for the cluster.
     */
    configurationInfo?: pulumi.Input<inputs.msk.ClusterConfigurationInfoArgs>;
    /**
     * The current version of the MSK cluster
     */
    currentVersion?: pulumi.Input<string>;
    /**
     * Includes all encryption-related information.
     */
    encryptionInfo?: pulumi.Input<inputs.msk.ClusterEncryptionInfoArgs>;
    /**
     * Specifies the level of monitoring for the MSK cluster.
     */
    enhancedMonitoring?: pulumi.Input<enums.msk.ClusterEnhancedMonitoring>;
    /**
     * The version of Apache Kafka. You can use Amazon MSK to create clusters that use [supported Apache Kafka versions](https://docs.aws.amazon.com/msk/latest/developerguide/supported-kafka-versions.html) .
     */
    kafkaVersion: pulumi.Input<string>;
    /**
     * Logging info details for the cluster.
     */
    loggingInfo?: pulumi.Input<inputs.msk.ClusterLoggingInfoArgs>;
    /**
     * The number of broker nodes in the cluster.
     */
    numberOfBrokerNodes: pulumi.Input<number>;
    /**
     * The settings for open monitoring.
     */
    openMonitoring?: pulumi.Input<inputs.msk.ClusterOpenMonitoringArgs>;
    /**
     * This controls storage mode for supported storage tiers.
     */
    storageMode?: pulumi.Input<enums.msk.ClusterStorageMode>;
    /**
     * A key-value pair to associate with a resource.
     */
    tags?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
}
