import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * The AWS::Neptune::DBSubnetGroup type creates an Amazon Neptune DB subnet group. Subnet groups must contain at least two subnets in two different Availability Zones in the same AWS Region.
 */
export declare class DbSubnetGroup extends pulumi.CustomResource {
    /**
     * Get an existing DbSubnetGroup resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): DbSubnetGroup;
    /**
     * Returns true if the given object is an instance of DbSubnetGroup.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is DbSubnetGroup;
    /**
     * The description for the DB subnet group.
     */
    readonly dbSubnetGroupDescription: pulumi.Output<string>;
    /**
     * The name for the DB subnet group. This value is stored as a lowercase string.
     *
     * Constraints: Must contain no more than 255 lowercase alphanumeric characters or hyphens. Must not be "Default".
     *
     * Example: mysubnetgroup
     */
    readonly dbSubnetGroupName: pulumi.Output<string | undefined>;
    /**
     * The Amazon EC2 subnet IDs for the DB subnet group.
     */
    readonly subnetIds: pulumi.Output<string[]>;
    /**
     * An optional array of key-value pairs to apply to this DB subnet group.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Create a DbSubnetGroup resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: DbSubnetGroupArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a DbSubnetGroup resource.
 */
export interface DbSubnetGroupArgs {
    /**
     * The description for the DB subnet group.
     */
    dbSubnetGroupDescription: pulumi.Input<string>;
    /**
     * The name for the DB subnet group. This value is stored as a lowercase string.
     *
     * Constraints: Must contain no more than 255 lowercase alphanumeric characters or hyphens. Must not be "Default".
     *
     * Example: mysubnetgroup
     */
    dbSubnetGroupName?: pulumi.Input<string>;
    /**
     * The Amazon EC2 subnet IDs for the DB subnet group.
     */
    subnetIds: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * An optional array of key-value pairs to apply to this DB subnet group.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
