import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * Definition of the AWS::QuickSight::Template Resource Type.
 */
export declare function getTemplate(args: GetTemplateArgs, opts?: pulumi.InvokeOptions): Promise<GetTemplateResult>;
export interface GetTemplateArgs {
    /**
     * The ID for the AWS account that the group is in. You use the ID for the AWS account that contains your Amazon QuickSight account.
     */
    awsAccountId: string;
    /**
     * An ID for the template that you want to create. This template is unique per AWS Region ; in each AWS account.
     */
    templateId: string;
}
export interface GetTemplateResult {
    /**
     * <p>The Amazon Resource Name (ARN) of the template.</p>
     */
    readonly arn?: string;
    /**
     * <p>Time when this was created.</p>
     */
    readonly createdTime?: string;
    /**
     * <p>Time when this was last updated.</p>
     */
    readonly lastUpdatedTime?: string;
    /**
     * A display name for the template.
     */
    readonly name?: string;
    /**
     * A list of resource permissions to be set on the template.
     */
    readonly permissions?: outputs.quicksight.TemplateResourcePermission[];
    /**
     * Contains a map of the key-value pairs for the resource tag or tags assigned to the resource.
     */
    readonly tags?: outputs.Tag[];
    readonly version?: outputs.quicksight.TemplateVersion;
}
/**
 * Definition of the AWS::QuickSight::Template Resource Type.
 */
export declare function getTemplateOutput(args: GetTemplateOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetTemplateResult>;
export interface GetTemplateOutputArgs {
    /**
     * The ID for the AWS account that the group is in. You use the ID for the AWS account that contains your Amazon QuickSight account.
     */
    awsAccountId: pulumi.Input<string>;
    /**
     * An ID for the template that you want to create. This template is unique per AWS Region ; in each AWS account.
     */
    templateId: pulumi.Input<string>;
}
