import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Definition of AWS::RefactorSpaces::Service Resource Type
 */
export declare class Service extends pulumi.CustomResource {
    /**
     * Get an existing Service resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): Service;
    /**
     * Returns true if the given object is an instance of Service.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Service;
    /**
     * The unique identifier of the application.
     */
    readonly applicationIdentifier: pulumi.Output<string>;
    /**
     * The Amazon Resource Name (ARN) of the service.
     */
    readonly arn: pulumi.Output<string>;
    /**
     * A description of the service.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * The endpoint type of the service.
     */
    readonly endpointType: pulumi.Output<enums.refactorspaces.ServiceEndpointType>;
    /**
     * The unique identifier of the environment.
     */
    readonly environmentIdentifier: pulumi.Output<string>;
    /**
     * A summary of the configuration for the AWS Lambda endpoint type.
     */
    readonly lambdaEndpoint: pulumi.Output<outputs.refactorspaces.ServiceLambdaEndpointInput | undefined>;
    /**
     * The name of the service.
     */
    readonly name: pulumi.Output<string>;
    /**
     * The unique identifier of the service.
     */
    readonly serviceIdentifier: pulumi.Output<string>;
    /**
     * Metadata that you can assign to help organize the frameworks that you create. Each tag is a key-value pair.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * The summary of the configuration for the URL endpoint type.
     */
    readonly urlEndpoint: pulumi.Output<outputs.refactorspaces.ServiceUrlEndpointInput | undefined>;
    /**
     * The ID of the virtual private cloud (VPC).
     */
    readonly vpcId: pulumi.Output<string | undefined>;
    /**
     * Create a Service resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: ServiceArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a Service resource.
 */
export interface ServiceArgs {
    /**
     * The unique identifier of the application.
     */
    applicationIdentifier: pulumi.Input<string>;
    /**
     * A description of the service.
     */
    description?: pulumi.Input<string>;
    /**
     * The endpoint type of the service.
     */
    endpointType: pulumi.Input<enums.refactorspaces.ServiceEndpointType>;
    /**
     * The unique identifier of the environment.
     */
    environmentIdentifier: pulumi.Input<string>;
    /**
     * A summary of the configuration for the AWS Lambda endpoint type.
     */
    lambdaEndpoint?: pulumi.Input<inputs.refactorspaces.ServiceLambdaEndpointInputArgs>;
    /**
     * The name of the service.
     */
    name?: pulumi.Input<string>;
    /**
     * Metadata that you can assign to help organize the frameworks that you create. Each tag is a key-value pair.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
    /**
     * The summary of the configuration for the URL endpoint type.
     */
    urlEndpoint?: pulumi.Input<inputs.refactorspaces.ServiceUrlEndpointInputArgs>;
    /**
     * The ID of the virtual private cloud (VPC).
     */
    vpcId?: pulumi.Input<string>;
}
