import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Resource Type Definition for AWS::ResilienceHub::App.
 */
export declare class App extends pulumi.CustomResource {
    /**
     * Get an existing App resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): App;
    /**
     * Returns true if the given object is an instance of App.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is App;
    /**
     * Amazon Resource Name (ARN) of the App.
     */
    readonly appArn: pulumi.Output<string>;
    /**
     * Assessment execution schedule.
     */
    readonly appAssessmentSchedule: pulumi.Output<enums.resiliencehub.AppAssessmentSchedule | undefined>;
    /**
     * A string containing full ResilienceHub app template body.
     */
    readonly appTemplateBody: pulumi.Output<string>;
    /**
     * App description.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * Indicates if compliance drifts (deviations) were detected while running an assessment for your application.
     */
    readonly driftStatus: pulumi.Output<enums.resiliencehub.AppDriftStatus>;
    /**
     * The list of events you would like to subscribe and get notification for.
     */
    readonly eventSubscriptions: pulumi.Output<outputs.resiliencehub.AppEventSubscription[] | undefined>;
    /**
     * Name of the app.
     */
    readonly name: pulumi.Output<string>;
    /**
     * Defines the roles and credentials that AWS Resilience Hub would use while creating the application, importing its resources, and running an assessment.
     */
    readonly permissionModel: pulumi.Output<outputs.resiliencehub.AppPermissionModel | undefined>;
    /**
     * Amazon Resource Name (ARN) of the Resiliency Policy.
     */
    readonly resiliencyPolicyArn: pulumi.Output<string | undefined>;
    /**
     * An array of ResourceMapping objects.
     */
    readonly resourceMappings: pulumi.Output<outputs.resiliencehub.AppResourceMapping[]>;
    /**
     * Tags assigned to the resource. A tag is a label that you assign to an AWS resource. Each tag consists of a key/value pair.
     */
    readonly tags: pulumi.Output<{
        [key: string]: string;
    } | undefined>;
    /**
     * Create a App resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: AppArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a App resource.
 */
export interface AppArgs {
    /**
     * Assessment execution schedule.
     */
    appAssessmentSchedule?: pulumi.Input<enums.resiliencehub.AppAssessmentSchedule>;
    /**
     * A string containing full ResilienceHub app template body.
     */
    appTemplateBody: pulumi.Input<string>;
    /**
     * App description.
     */
    description?: pulumi.Input<string>;
    /**
     * The list of events you would like to subscribe and get notification for.
     */
    eventSubscriptions?: pulumi.Input<pulumi.Input<inputs.resiliencehub.AppEventSubscriptionArgs>[]>;
    /**
     * Name of the app.
     */
    name?: pulumi.Input<string>;
    /**
     * Defines the roles and credentials that AWS Resilience Hub would use while creating the application, importing its resources, and running an assessment.
     */
    permissionModel?: pulumi.Input<inputs.resiliencehub.AppPermissionModelArgs>;
    /**
     * Amazon Resource Name (ARN) of the Resiliency Policy.
     */
    resiliencyPolicyArn?: pulumi.Input<string>;
    /**
     * An array of ResourceMapping objects.
     */
    resourceMappings: pulumi.Input<pulumi.Input<inputs.resiliencehub.AppResourceMappingArgs>[]>;
    /**
     * Tags assigned to the resource. A tag is a label that you assign to an AWS resource. Each tag consists of a key/value pair.
     */
    tags?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
}
