import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Creates an Amazon S3 Tables table bucket in the same AWS Region where you create the AWS CloudFormation stack.
 */
export declare class TableBucket extends pulumi.CustomResource {
    /**
     * Get an existing TableBucket resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): TableBucket;
    /**
     * Returns true if the given object is an instance of TableBucket.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is TableBucket;
    /**
     * Configuration specifying how data should be encrypted. This structure defines the encryption algorithm and optional KMS key to be used for server-side encryption.
     */
    readonly encryptionConfiguration: pulumi.Output<outputs.s3tables.TableBucketEncryptionConfiguration | undefined>;
    /**
     * The Amazon Resource Name (ARN) of the table bucket.
     */
    readonly tableBucketArn: pulumi.Output<string>;
    /**
     * The name for the table bucket.
     */
    readonly tableBucketName: pulumi.Output<string>;
    /**
     * The unreferenced file removal settings for your table bucket. Unreferenced file removal identifies and deletes all objects that are not referenced by any table snapshots. For more information, see the [*Amazon S3 User Guide*](https://docs.aws.amazon.com/AmazonS3/latest/userguide/s3-table-buckets-maintenance.html) .
     */
    readonly unreferencedFileRemoval: pulumi.Output<outputs.s3tables.TableBucketUnreferencedFileRemoval | undefined>;
    /**
     * Create a TableBucket resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: TableBucketArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a TableBucket resource.
 */
export interface TableBucketArgs {
    /**
     * Configuration specifying how data should be encrypted. This structure defines the encryption algorithm and optional KMS key to be used for server-side encryption.
     */
    encryptionConfiguration?: pulumi.Input<inputs.s3tables.TableBucketEncryptionConfigurationArgs>;
    /**
     * The name for the table bucket.
     */
    tableBucketName?: pulumi.Input<string>;
    /**
     * The unreferenced file removal settings for your table bucket. Unreferenced file removal identifies and deletes all objects that are not referenced by any table snapshots. For more information, see the [*Amazon S3 User Guide*](https://docs.aws.amazon.com/AmazonS3/latest/userguide/s3-table-buckets-maintenance.html) .
     */
    unreferencedFileRemoval?: pulumi.Input<inputs.s3tables.TableBucketUnreferencedFileRemovalArgs>;
}
