import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Resource Type definition for AWS::SageMaker::InferenceComponent
 */
export declare function getInferenceComponent(args: GetInferenceComponentArgs, opts?: pulumi.InvokeOptions): Promise<GetInferenceComponentResult>;
export interface GetInferenceComponentArgs {
    /**
     * The Amazon Resource Name (ARN) of the inference component.
     */
    inferenceComponentArn: string;
}
export interface GetInferenceComponentResult {
    /**
     * The time when the inference component was created.
     */
    readonly creationTime?: string;
    /**
     * The Amazon Resource Name (ARN) of the endpoint that hosts the inference component.
     */
    readonly endpointArn?: string;
    /**
     * The name of the endpoint that hosts the inference component.
     */
    readonly endpointName?: string;
    readonly failureReason?: string;
    /**
     * The Amazon Resource Name (ARN) of the inference component.
     */
    readonly inferenceComponentArn?: string;
    /**
     * The name of the inference component.
     */
    readonly inferenceComponentName?: string;
    /**
     * The status of the inference component.
     */
    readonly inferenceComponentStatus?: enums.sagemaker.InferenceComponentStatus;
    /**
     * The time when the inference component was last updated.
     */
    readonly lastModifiedTime?: string;
    readonly runtimeConfig?: outputs.sagemaker.InferenceComponentRuntimeConfig;
    readonly specification?: outputs.sagemaker.InferenceComponentSpecification;
    readonly tags?: outputs.Tag[];
    /**
     * The name of the production variant that hosts the inference component.
     */
    readonly variantName?: string;
}
/**
 * Resource Type definition for AWS::SageMaker::InferenceComponent
 */
export declare function getInferenceComponentOutput(args: GetInferenceComponentOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetInferenceComponentResult>;
export interface GetInferenceComponentOutputArgs {
    /**
     * The Amazon Resource Name (ARN) of the inference component.
     */
    inferenceComponentArn: pulumi.Input<string>;
}
