import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Definition of AWS::SSMGuiConnect::Preferences Resource Type
 */
export declare class Preferences extends pulumi.CustomResource {
    /**
     * Get an existing Preferences resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): Preferences;
    /**
     * Returns true if the given object is an instance of Preferences.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Preferences;
    /**
     * The AWS Account Id that the preference is associated with, used as the unique identifier for this resource.
     */
    readonly accountId: pulumi.Output<string>;
    /**
     * The set of preferences used for recording RDP connections in the requesting AWS account and AWS Region. This includes details such as which S3 bucket recordings are stored in.
     */
    readonly connectionRecordingPreferences: pulumi.Output<outputs.ssmguiconnect.ConnectionRecordingPreferencesProperties | undefined>;
    /**
     * Create a Preferences resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: PreferencesArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a Preferences resource.
 */
export interface PreferencesArgs {
    /**
     * The set of preferences used for recording RDP connections in the requesting AWS account and AWS Region. This includes details such as which S3 bucket recordings are stored in.
     */
    connectionRecordingPreferences?: pulumi.Input<inputs.ssmguiconnect.ConnectionRecordingPreferencesPropertiesArgs>;
}
