import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * Creates a listener rule. Each listener has a default rule for checking connection requests, but you can define additional rules. Each rule consists of a priority, one or more actions, and one or more conditions.
 */
export declare function getRule(args: GetRuleArgs, opts?: pulumi.InvokeOptions): Promise<GetRuleResult>;
export interface GetRuleArgs {
    /**
     * The Amazon Resource Name (ARN) of the rule.
     */
    arn: string;
}
export interface GetRuleResult {
    /**
     * Describes the action for a rule.
     */
    readonly action?: outputs.vpclattice.RuleAction;
    /**
     * The Amazon Resource Name (ARN) of the rule.
     */
    readonly arn?: string;
    /**
     * The ID of the listener.
     */
    readonly id?: string;
    /**
     * The rule match.
     */
    readonly match?: outputs.vpclattice.RuleMatch;
    /**
     * The priority assigned to the rule. Each rule for a specific listener must have a unique priority. The lower the priority number the higher the priority.
     */
    readonly priority?: number;
    /**
     * The tags for the rule.
     */
    readonly tags?: outputs.Tag[];
}
/**
 * Creates a listener rule. Each listener has a default rule for checking connection requests, but you can define additional rules. Each rule consists of a priority, one or more actions, and one or more conditions.
 */
export declare function getRuleOutput(args: GetRuleOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetRuleResult>;
export interface GetRuleOutputArgs {
    /**
     * The Amazon Resource Name (ARN) of the rule.
     */
    arn: pulumi.Input<string>;
}
