import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Contains a list of Regular expressions based on the provided inputs. RegexPatternSet can be used with other WAF entities with RegexPatternSetReferenceStatement to perform other actions .
 */
export declare function getRegexPatternSet(args: GetRegexPatternSetArgs, opts?: pulumi.InvokeOptions): Promise<GetRegexPatternSetResult>;
export interface GetRegexPatternSetArgs {
    /**
     * Id of the RegexPatternSet
     */
    id: string;
    /**
     * Name of the RegexPatternSet.
     */
    name: string;
    /**
     * Use CLOUDFRONT for CloudFront RegexPatternSet, use REGIONAL for Application Load Balancer and API Gateway.
     */
    scope: enums.wafv2.RegexPatternSetScope;
}
export interface GetRegexPatternSetResult {
    /**
     * ARN of the WAF entity.
     */
    readonly arn?: string;
    /**
     * Description of the entity.
     */
    readonly description?: string;
    /**
     * Id of the RegexPatternSet
     */
    readonly id?: string;
    /**
     * The regular expression patterns in the set.
     */
    readonly regularExpressionList?: string[];
    /**
     * Key:value pairs associated with an AWS resource. The key:value pair can be anything you define. Typically, the tag key represents a category (such as "environment") and the tag value represents a specific value within that category (such as "test," "development," or "production"). You can add up to 50 tags to each AWS resource.
     *
     * > To modify tags on existing resources, use the AWS WAF APIs or command line interface. With AWS CloudFormation , you can only add tags to AWS WAF resources during resource creation.
     */
    readonly tags?: outputs.Tag[];
}
/**
 * Contains a list of Regular expressions based on the provided inputs. RegexPatternSet can be used with other WAF entities with RegexPatternSetReferenceStatement to perform other actions .
 */
export declare function getRegexPatternSetOutput(args: GetRegexPatternSetOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetRegexPatternSetResult>;
export interface GetRegexPatternSetOutputArgs {
    /**
     * Id of the RegexPatternSet
     */
    id: pulumi.Input<string>;
    /**
     * Name of the RegexPatternSet.
     */
    name: pulumi.Input<string>;
    /**
     * Use CLOUDFRONT for CloudFront RegexPatternSet, use REGIONAL for Application Load Balancer and API Gateway.
     */
    scope: pulumi.Input<enums.wafv2.RegexPatternSetScope>;
}
