import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * This schema provides construct and validation rules for AWS-XRay Group resource parameters.
 *
 * ## Example Usage
 * ### Example
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws_native from "@pulumi/aws-native";
 *
 * const myGroupResource = new aws_native.xray.Group("myGroupResource", {
 *     groupName: "MyGroup",
 *     filterExpression: "duration > 10",
 *     insightsConfiguration: {
 *         insightsEnabled: false,
 *         notificationsEnabled: false,
 *     },
 * });
 *
 * ```
 * ### Example
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws_native from "@pulumi/aws-native";
 *
 * const myGroupResource = new aws_native.xray.Group("myGroupResource", {
 *     groupName: "MyGroup",
 *     filterExpression: "duration > 10",
 *     insightsConfiguration: {
 *         insightsEnabled: false,
 *         notificationsEnabled: false,
 *     },
 * });
 *
 * ```
 */
export declare class Group extends pulumi.CustomResource {
    /**
     * Get an existing Group resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): Group;
    /**
     * Returns true if the given object is an instance of Group.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Group;
    /**
     * The filter expression defining criteria by which to group traces.
     */
    readonly filterExpression: pulumi.Output<string | undefined>;
    /**
     * The ARN of the group that was generated on creation.
     */
    readonly groupArn: pulumi.Output<string>;
    /**
     * The case-sensitive name of the new group. Names must be unique.
     */
    readonly groupName: pulumi.Output<string>;
    /**
     * The structure containing configurations related to insights.
     *
     * - The InsightsEnabled boolean can be set to true to enable insights for the group or false to disable insights for the group.
     * - The NotificationsEnabled boolean can be set to true to enable insights notifications through Amazon EventBridge for the group.
     */
    readonly insightsConfiguration: pulumi.Output<outputs.xray.GroupInsightsConfiguration | undefined>;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Create a Group resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: GroupArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a Group resource.
 */
export interface GroupArgs {
    /**
     * The filter expression defining criteria by which to group traces.
     */
    filterExpression?: pulumi.Input<string>;
    /**
     * The case-sensitive name of the new group. Names must be unique.
     */
    groupName?: pulumi.Input<string>;
    /**
     * The structure containing configurations related to insights.
     *
     * - The InsightsEnabled boolean can be set to true to enable insights for the group or false to disable insights for the group.
     * - The NotificationsEnabled boolean can be set to true to enable insights notifications through Amazon EventBridge for the group.
     */
    insightsConfiguration?: pulumi.Input<inputs.xray.GroupInsightsConfigurationArgs>;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
