import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Resource Type definition for AWS::GuardDuty::MalwareProtectionPlan
 */
export declare class MalwareProtectionPlan extends pulumi.CustomResource {
    /**
     * Get an existing MalwareProtectionPlan resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): MalwareProtectionPlan;
    /**
     * Returns true if the given object is an instance of MalwareProtectionPlan.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is MalwareProtectionPlan;
    /**
     * Specifies the action that is to be applied to the Malware Protection plan resource.
     */
    readonly actions: pulumi.Output<outputs.guardduty.MalwareProtectionPlanCfnActions | undefined>;
    /**
     * Amazon Resource Name (ARN) of the protected resource.
     */
    readonly arn: pulumi.Output<string>;
    /**
     * The timestamp when the Malware Protection plan resource was created.
     */
    readonly createdAt: pulumi.Output<string>;
    /**
     * A unique identifier associated with Malware Protection plan resource.
     */
    readonly malwareProtectionPlanId: pulumi.Output<string>;
    /**
     * Information about the protected resource. Presently, S3Bucket is the only supported protected resource.
     */
    readonly protectedResource: pulumi.Output<outputs.guardduty.MalwareProtectionPlanCfnProtectedResource>;
    /**
     * IAM role that includes the permissions required to scan and (optionally) add tags to the associated protected resource.
     */
    readonly role: pulumi.Output<string>;
    /**
     * Status of the Malware Protection plan resource.
     */
    readonly status: pulumi.Output<string>;
    /**
     * Status details associated with the Malware Protection plan resource status.
     */
    readonly statusReasons: pulumi.Output<outputs.guardduty.MalwareProtectionPlanCfnStatusReasons[]>;
    /**
     * The tags to be added to the created Malware Protection plan resource. Each tag consists of a key and an optional value, both of which you need to specify.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Create a MalwareProtectionPlan resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: MalwareProtectionPlanArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a MalwareProtectionPlan resource.
 */
export interface MalwareProtectionPlanArgs {
    /**
     * Specifies the action that is to be applied to the Malware Protection plan resource.
     */
    actions?: pulumi.Input<inputs.guardduty.MalwareProtectionPlanCfnActionsArgs>;
    /**
     * Information about the protected resource. Presently, S3Bucket is the only supported protected resource.
     */
    protectedResource: pulumi.Input<inputs.guardduty.MalwareProtectionPlanCfnProtectedResourceArgs>;
    /**
     * IAM role that includes the permissions required to scan and (optionally) add tags to the associated protected resource.
     */
    role: pulumi.Input<string>;
    /**
     * The tags to be added to the created Malware Protection plan resource. Each tag consists of a key and an optional value, both of which you need to specify.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
